@@ -23,14 +23,6 @@ def parse(sql_text, start="sql_script", strict=False):
 import yaml
 
 
-def parse_from_yaml(fname):
-    data = yaml.load(open(fname)) if isinstance(fname, str) else fname
-    out = {}
-    for start, cmds in data.items():
-        out[start] = [parse(cmd, start) for cmd in cmds]
-    return out
-
-
 class Unshaped(AstNode):
     _fields_spec = ["arr"]
 
